@@ -30,3 +30,14 @@ def taskchecker():
         sys.exit(1)
         time.sleep(0.5)        
 
+    CONTAINERNAME='webapp'
+    client = docker.from_env()
+    container = client.containers.list(filters={'name': CONTAINERNAME})
+    container = str(container)
+    if "Container" in container:
+        print(bcolors.OKGREEN + "%s container is created" % CONTAINERNAME + bcolors.ENDC)
+        time.sleep(0.5)
+    else:
+        print(bcolors.FAIL + "%s container is not  created" % CONTAINERNAME  + bcolors.ENDC)
+        sys.exit(1)
+        time.sleep(0.5)  
\ No newline at end of file
